@@ -46,6 +46,9 @@
 #include "input/input_event.h"
 #include "ui/root.h"
 
+#include "command_scheduler.h"
+#include "option_handler.h"
+
 #include "control.h"
 
 Control::Control() :
@@ -55,18 +58,28 @@ Control::Control() :
   m_core(new core::Manager()),
   m_display(new display::Manager()),
   m_input(new input::Manager()),
-  m_inputStdin(new input::InputEvent(STDIN_FILENO)) {
+  m_inputStdin(new input::InputEvent(STDIN_FILENO)),
+
+  m_commandScheduler(new CommandScheduler()),
+  m_optionHandler(new OptionHandler()),
+
+  m_tick(0) {
 
   m_inputStdin->slot_pressed(sigc::mem_fun(m_input, &input::Manager::pressed));
 
-  m_taskShutdown.set_iterator(utils::taskScheduler.end());
-  m_taskShutdown.set_slot(sigc::mem_fun(*this, &Control::receive_shutdown));
+  m_taskShutdown.set_slot(rak::mem_fn(this, &Control::receive_shutdown));
+
+  m_commandScheduler->set_slot_command(rak::mem_fn(m_optionHandler, &OptionHandler::process_command));
+  m_commandScheduler->set_slot_error_message(rak::mem_fn(m_core, &core::Manager::push_log));
 }
 
 Control::~Control() {
   delete m_inputStdin;
   delete m_input;
 
+  delete m_commandScheduler;
+  delete m_optionHandler;
+
   delete m_ui;
   delete m_display;
   delete m_core;
@@ -75,12 +88,16 @@ Control::~Control() {
 void
 Control::initialize() {
   display::Canvas::initialize();
-  display::Window::slot_adjust(sigc::mem_fun(m_display, &display::Manager::adjust_layout));
+  display::Window::slot_schedule(rak::make_mem_fun(m_display, &display::Manager::schedule));
+  display::Window::slot_unschedule(rak::make_mem_fun(m_display, &display::Manager::unschedule));
+  display::Window::slot_adjust(rak::make_mem_fun(m_display, &display::Manager::adjust_layout));
 
   m_core->get_poll_manager()->signal_interrupted().connect(sigc::mem_fun(*m_inputStdin, &input::InputEvent::event_read));
   m_core->get_poll_manager()->signal_interrupted().connect(sigc::ptr_fun(display::Canvas::do_update));
+  m_core->get_poll_manager()->get_http_stack()->set_user_agent(std::string(PACKAGE "/" VERSION "/") + torrent::version());
 
   m_core->initialize_second();
+  m_core->listen_open();
 
   m_ui->init(this);
 
@@ -89,7 +106,7 @@ Control::initialize() {
 
 void
 Control::cleanup() {
-  utils::taskScheduler.erase(&m_taskShutdown);
+  priority_queue_erase(&taskScheduler, &m_taskShutdown);
 
   m_inputStdin->remove(m_core->get_poll_manager()->get_torrent_poll());
 
@@ -112,8 +129,8 @@ Control::receive_shutdown() {
     m_core->shutdown(false);
     m_shutdownReceived = true;
 
-    if (!utils::taskScheduler.is_scheduled(&m_taskShutdown))
-      utils::taskScheduler.insert(&m_taskShutdown, utils::Timer::cache() + 5 * 1000000);
+    if (!m_taskShutdown.is_queued())
+      priority_queue_insert(&taskScheduler, &m_taskShutdown, cachedTime + 5 * 1000000);
 
   } else {
     m_core->shutdown(true);
