@@ -37,9 +37,10 @@
 #ifndef RTORRENT_CONTROL_H
 #define RTORRENT_CONTROL_H
 
+#include <inttypes.h>
 #include <torrent/torrent.h>
 
-#include "utils/task.h"
+#include "globals.h"
 
 namespace ui {
   class Root;
@@ -58,6 +59,9 @@ namespace input {
   class Manager;
 }  
 
+class OptionHandler;
+class CommandScheduler;
+
 class Control {
 public:
   Control();
@@ -66,16 +70,22 @@ public:
   bool                is_shutdown_completed()       { return m_shutdownReceived && torrent::is_inactive(); }
   bool                is_shutdown_received()        { return m_shutdownReceived; }
 
+  void                initialize();
+  void                cleanup();
+
+  void                receive_shutdown();
+
   ui::Root*           ui()                          { return m_ui; }
   core::Manager*      core()                        { return m_core; }
   display::Manager*   display()                     { return m_display; }
   input::Manager*     input()                       { return m_input; }
   input::InputEvent*  input_stdin()                 { return m_inputStdin; }
 
-  void                initialize();
-  void                cleanup();
+  CommandScheduler*   command_scheduler()           { return m_commandScheduler; }
+  OptionHandler*      option_handler()              { return m_optionHandler; }
 
-  void                receive_shutdown();
+  uint64_t            tick() const                  { return m_tick; }
+  void                inc_tick()                    { m_tick++; }
 
 private:
   Control(const Control&);
@@ -89,7 +99,12 @@ private:
   input::Manager*     m_input;
   input::InputEvent*  m_inputStdin;
 
-  utils::TaskItem     m_taskShutdown;
+  CommandScheduler*   m_commandScheduler;
+  OptionHandler*      m_optionHandler;
+
+  uint64_t            m_tick;
+
+  rak::priority_item  m_taskShutdown;
 };
 
 #endif
