@@ -46,6 +46,14 @@
 
 namespace core {
 
+size_t
+curl_get_receive_write(void* data, size_t size, size_t nmemb, void* handle) {
+  if (!((CurlGet*)handle)->stream()->write((char*)data, size * nmemb).fail())
+    return size * nmemb;
+  else
+    return 0;
+}
+
 CurlGet::CurlGet(CurlStack* s) :
   m_handle(NULL),
   m_stack(s) {
@@ -73,12 +81,17 @@ CurlGet::start() {
 
   m_handle = curl_easy_init();
 
-  curl_easy_setopt(m_handle, CURLOPT_URL,           m_url.c_str());
-  curl_easy_setopt(m_handle, CURLOPT_USERAGENT,     m_userAgent.c_str());
-  curl_easy_setopt(m_handle, CURLOPT_WRITEFUNCTION, &curl_get_receive_write);
-  curl_easy_setopt(m_handle, CURLOPT_WRITEDATA,     this);
+  curl_easy_setopt(m_handle, CURLOPT_URL,            m_url.c_str());
+  curl_easy_setopt(m_handle, CURLOPT_WRITEFUNCTION,  &curl_get_receive_write);
+  curl_easy_setopt(m_handle, CURLOPT_WRITEDATA,      this);
+
+  if (m_timeout != 0) {
+    curl_easy_setopt(m_handle, CURLOPT_CONNECTTIMEOUT, 60);
+    curl_easy_setopt(m_handle, CURLOPT_TIMEOUT,        m_timeout);
+  }
 
   curl_easy_setopt(m_handle, CURLOPT_FORBID_REUSE,   1);
+  curl_easy_setopt(m_handle, CURLOPT_NOSIGNAL,       1);
   curl_easy_setopt(m_handle, CURLOPT_FOLLOWLOCATION, 1);
   curl_easy_setopt(m_handle, CURLOPT_MAXREDIRS,      5);
 
@@ -99,7 +112,7 @@ CurlGet::close() {
 
 
 double
-CurlGet::get_size_done() {
+CurlGet::size_done() {
   double d = 0.0;
   curl_easy_getinfo(m_handle, CURLINFO_SIZE_DOWNLOAD, &d);
 
@@ -107,13 +120,23 @@ CurlGet::get_size_done() {
 }
 
 double
-CurlGet::get_size_total() {
+CurlGet::size_total() {
   double d = 0.0;
   curl_easy_getinfo(m_handle, CURLINFO_CONTENT_LENGTH_DOWNLOAD, &d);
 
   return d;
 }
 
+void
+CurlGet::set_user_agent(const char* s) {
+  curl_easy_setopt(m_handle, CURLOPT_USERAGENT, s);
+}
+
+void
+CurlGet::set_http_proxy(const char* s) {
+  curl_easy_setopt(m_handle, CURLOPT_PROXY, s);
+}
+
 void
 CurlGet::perform(CURLMsg* msg) {
   if (msg->msg != CURLMSG_DONE)
@@ -123,11 +146,10 @@ CurlGet::perform(CURLMsg* msg) {
     m_signalDone.emit();
   else
     m_signalFailed.emit(curl_easy_strerror(msg->data.result));
-}
 
-size_t
-curl_get_receive_write(void* data, size_t size, size_t nmemb, void* handle) {
-  return ((CurlGet*)handle)->m_stream->write((char*)data, size * nmemb).fail() ? 0 : size * nmemb;
+  if (m_handle != NULL)
+    throw std::logic_error("CurlGet::perform finished but the object wasn't closed.");
+
 }
 
 }
