@@ -61,13 +61,16 @@ class CurlGet : public torrent::Http {
   void               start();
   void               close();
 
-  bool               is_busy() { return m_handle; }
+  bool               is_busy()                      { return m_handle; }
 
-  double             get_size_done();
-  double             get_size_total();
+  double             size_done();
+  double             size_total();
+
+  void               set_user_agent(const char* s);
+  void               set_http_proxy(const char* s);
 
  protected:
-  CURL*              handle() { return m_handle; }
+  CURL*              handle()                       { return m_handle; }
 
   void               perform(CURLMsg* msg);
 
@@ -75,8 +78,6 @@ class CurlGet : public torrent::Http {
   CurlGet(const CurlGet&);
   void operator = (const CurlGet&);
 
-  friend size_t      curl_get_receive_write(void* data, size_t size, size_t nmemb, void* handle);
-
   CURL*              m_handle;
 
   CurlStack*         m_stack;
