@@ -103,6 +103,12 @@ CurlStack::fdset(fd_set* readfds, fd_set* writefds, fd_set* exceptfds) {
 
 void
 CurlStack::add_get(CurlGet* get) {
+  if (!m_userAgent.empty())
+    get->set_user_agent(m_userAgent.c_str());
+
+  if (!m_httpProxy.empty())
+    get->set_http_proxy(m_httpProxy.c_str());
+
   CURLMcode code;
 
   if ((code = curl_multi_add_handle((CURLM*)m_handle, get->handle())) > 0)
