@@ -40,51 +40,27 @@
 #include <sigc++/bind.h>
 #include <sigc++/hide.h>
 #include <sigc++/signal.h>
+#include <torrent/exceptions.h>
 
 #include "download.h"
 
 namespace core {
 
-Download::Download() :
+Download::Download(torrent::Download d) :
+  m_download(d),
+
+  m_chunksFailed(0),
   m_connectionLeech(torrent::Download::CONNECTION_LEECH),
   m_connectionSeed(torrent::Download::CONNECTION_SEED) {
-}
-
-void
-Download::start() {
-  if (is_done())
-    m_download.set_connection_type(m_connectionSeed);
-  else
-    m_download.set_connection_type(m_connectionLeech);
-
-  m_download.start();
-}
-
-void
-Download::set_download(torrent::Download d) {
-  m_download = d;
 
   m_connTrackerSucceded = m_download.signal_tracker_succeded(sigc::bind(sigc::mem_fun(*this, &Download::receive_tracker_msg), ""));
   m_connTrackerFailed = m_download.signal_tracker_failed(sigc::mem_fun(*this, &Download::receive_tracker_msg));
   m_connStorageError = m_download.signal_storage_error(sigc::mem_fun(*this, &Download::receive_storage_error));
+
+  m_download.signal_chunk_failed(sigc::mem_fun(*this, &Download::receive_chunk_failed));
 }
 
-void
-Download::set_root_directory(const std::string& d) {
-  m_download.set_root_dir(d +
-			  (!d.empty() && *d.rbegin() != '/' ? "/" : "") +
-			  (m_download.get_entry_size() > 1 ? m_download.get_name() : ""));
-}
-
-void
-Download::enable_udp_trackers(bool state) {
-  for (int i = 0, last = m_download.get_tracker_size(); i < last; ++i)
-    if (m_download.get_tracker(i).get_type() == torrent::Tracker::TRACKER_UDP)
-      m_download.get_tracker(i).enable(state);
-}
-
-void
-Download::release_download() {
+Download::~Download() {
   if (!m_download.is_valid())
     return;
 
@@ -95,9 +71,40 @@ Download::release_download() {
   m_download = torrent::Download();
 }
 
+void
+Download::start() {
+  if (is_done()) {
+    m_download.set_connection_type(m_connectionSeed);
+    torrent::download_set_priority(m_download, 2);
+  } else {
+    m_download.set_connection_type(m_connectionLeech);
+    torrent::download_set_priority(m_download, 4);
+  }
+
+  m_download.start();
+}
+
+void
+Download::set_root_directory(const std::string& d) {
+  m_download.set_root_dir(d +
+			  (!d.empty() && *d.rbegin() != '/' ? "/" : "") +
+			  (m_download.size_file_entries() > 1 ? m_download.name() : ""));
+}
+
+void
+Download::enable_udp_trackers(bool state) {
+  for (int i = 0, last = m_download.size_trackers(); i < last; ++i)
+    if (m_download.tracker(i).tracker_type() == torrent::Tracker::TRACKER_UDP)
+      if (state)
+	m_download.tracker(i).enable();
+      else
+	m_download.tracker(i).disable();
+}
+
 void
 Download::receive_finished() {
   m_download.set_connection_type(m_connectionSeed);
+  torrent::download_set_priority(m_download, 2);
 }
 
 void
@@ -121,7 +128,7 @@ Download::string_to_connection_type(const std::string& name) {
   else if (name == "seed")
     return torrent::Download::CONNECTION_SEED;
   else
-    throw std::runtime_error("Invalid connection type selected: \"" + name + "\"");
+    throw torrent::input_error("Unknown peer connection type selected: \"" + name + "\"");
 }
 
 const char*
@@ -136,4 +143,9 @@ Download::connection_type_to_string(torrent::Download::ConnectionType t) {
   }
 }
 
+void
+Download::receive_chunk_failed(uint32_t idx) {
+  m_chunksFailed++;
+}
+
 }
