@@ -47,33 +47,35 @@ class Download {
 public:
   typedef torrent::Download::ConnectionType ConnType;
 
-  Download();
-  ~Download() { release_download(); }
+  Download(torrent::Download d);
+  ~Download();
 
   bool               is_open()                       { return m_download.is_open(); }
   inline bool        is_done();
 
   void               start();
 
-  void               set_download(torrent::Download d);
-  void               release_download();
-
   torrent::Download& get_download()                  { return m_download; }
   const torrent::Download& get_download() const      { return m_download; }
-  std::string        get_hash()                      { return m_download.get_hash(); }
-  torrent::Bencode&  get_bencode()                   { return m_download.get_bencode(); }
+  std::string        get_hash()                      { return m_download.info_hash(); }
+  torrent::Bencode&  get_bencode()                   { return m_download.bencode(); }
   
   const std::string& get_message()                   { return m_message; }
 
+  uint32_t           chunks_failed() const                         { return m_chunksFailed; }
+
   void               set_root_directory(const std::string& d);
 
-  ConnType           get_connection_current() const                { return m_download.get_connection_type(); }
+  ConnType           get_connection_current() const                { return m_download.connection_type(); }
   ConnType           get_connection_leech() const                  { return m_connectionLeech; }
   ConnType           get_connection_seed() const                   { return m_connectionSeed; }
 
   void               set_connection_leech(const std::string& name) { m_connectionLeech = string_to_connection_type(name); }
   void               set_connection_seed(const std::string& name)  { m_connectionSeed = string_to_connection_type(name); }
 
+  const std::string& tied_to_file() const                          { return m_tiedToFile; }
+  void               set_tied_to_file(const std::string& str)      { m_tiedToFile = str; }
+
   void               enable_udp_trackers(bool state);
 
   // Helper functions for calling functions in torrent::Download
@@ -84,7 +86,7 @@ public:
   template <typename Ret, typename Arg1, Ret (torrent::Download::*func)(Arg1)>
   void               call(Arg1 a1)                                         { (m_download.*func)(a1); }
 
-  bool operator == (const std::string& str)                                { return str == m_download.get_hash(); }
+  bool operator == (const std::string& str)                                { return str == m_download.info_hash(); }
 
   void               receive_finished();
 
@@ -95,13 +97,18 @@ private:
   void               receive_tracker_msg(std::string msg);
   void               receive_storage_error(std::string msg);
 
+  void               receive_chunk_failed(uint32_t idx);
+
   torrent::Download  m_download;
 
   std::string        m_message;
+  uint32_t           m_chunksFailed;
 
   ConnType           m_connectionLeech;
   ConnType           m_connectionSeed;
 
+  std::string        m_tiedToFile;
+
   sigc::connection   m_connTrackerSucceded;
   sigc::connection   m_connTrackerFailed;
   sigc::connection   m_connStorageError;
@@ -109,7 +116,7 @@ private:
 
 inline bool
 Download::is_done() {
-  return m_download.get_chunks_done() == m_download.get_chunks_total();
+  return m_download.chunks_done() == m_download.chunks_total();
 }
 
 }
