@@ -61,8 +61,11 @@ PollManagerEPoll::~PollManagerEPoll() {
 }
 
 void
-PollManagerEPoll::poll(utils::Timer timeout) {
-  timeout = std::min(timeout, utils::Timer(torrent::get_next_timeout()));
+PollManagerEPoll::poll(rak::timer timeout) {
+  // Add 1ms to ensure we don't idle loop due to the lack of
+  // resolution.
+  torrent::perform();
+  timeout = std::min(timeout, rak::timer(torrent::next_timeout()));
 
   if (m_httpStack.is_busy()) {
     // When we're using libcurl we need to use select, but as this is
@@ -76,9 +79,9 @@ PollManagerEPoll::poll(utils::Timer timeout) {
     FD_ZERO(m_writeSet);
     FD_ZERO(m_errorSet);
 #endif    
-    FD_SET(static_cast<torrent::PollEPoll*>(m_poll)->get_fd(), m_readSet);
+    FD_SET(static_cast<torrent::PollEPoll*>(m_poll)->file_descriptor(), m_readSet);
 
-    unsigned int maxFd = std::max((unsigned int)static_cast<torrent::PollEPoll*>(m_poll)->get_fd(),
+    unsigned int maxFd = std::max((unsigned int)static_cast<torrent::PollEPoll*>(m_poll)->file_descriptor(),
 				  m_httpStack.fdset(m_readSet, m_writeSet, m_errorSet));
 
     timeval t = timeout.tval();
@@ -88,7 +91,7 @@ PollManagerEPoll::poll(utils::Timer timeout) {
 
     m_httpStack.perform();
 
-    if (!FD_ISSET(static_cast<torrent::PollEPoll*>(m_poll)->get_fd(), m_readSet)) {
+    if (!FD_ISSET(static_cast<torrent::PollEPoll*>(m_poll)->file_descriptor(), m_readSet)) {
       // Need to call perform here so that scheduled task get done
       // even if there's no socket events outside of the http stuff.
       torrent::perform();
@@ -96,18 +99,17 @@ PollManagerEPoll::poll(utils::Timer timeout) {
     }
 
     // Clear the timeout since we've already used it in the select call.
-    timeout = utils::Timer();
+    timeout = rak::timer();
   }
 
   // Yes, below is how much code really *should* have been in this
   // function. ;)
-  torrent::perform();
 
-  if (static_cast<torrent::PollEPoll*>(m_poll)->poll(timeout.usec() / 1000) == -1)
+  if (static_cast<torrent::PollEPoll*>(m_poll)->poll((timeout.usec() + 999) / 1000) == -1)
     return check_error();
 
-  static_cast<torrent::PollEPoll*>(m_poll)->perform();
   torrent::perform();
+  static_cast<torrent::PollEPoll*>(m_poll)->perform();
 }
 
 }
