@@ -39,6 +39,7 @@
 #include <torrent/rate.h>
 
 #include "canvas.h"
+#include "globals.h"
 #include "utils.h"
 #include "window_download_statusbar.h"
 
@@ -53,7 +54,7 @@ WindowDownloadStatusbar::WindowDownloadStatusbar(core::Download* d) :
 
 void
 WindowDownloadStatusbar::redraw() {
-  utils::displayScheduler.insert(&m_taskUpdate, (utils::Timer::cache() + 1000000).round_seconds());
+  m_slotSchedule(this, (cachedTime + 1000000).round_seconds());
 
   m_canvas->erase();
 
@@ -64,32 +65,20 @@ WindowDownloadStatusbar::redraw() {
   position = print_download_info(buffer, last - buffer, m_download);
   m_canvas->print(0, 0, "%s", buffer);
 
-//   if (m_download->get_download().get_chunks_done() != m_download->get_download().get_chunks_total() || !m_download->get_download().is_open())
-//     m_canvas->print(0, 0, "Torrent: %.1f / %.1f MiB Rate: %5.1f / %5.1f KiB Uploaded: %.1f MiB",
-// 		    (double)m_download->get_download().get_bytes_done() / (double)(1 << 20),
-// 		    (double)m_download->get_download().get_bytes_total() / (double)(1 << 20),
-// 		    (double)m_download->get_download().get_write_rate().rate() / 1024.0,
-// 		    (double)m_download->get_download().get_read_rate().rate() / 1024.0,
-// 		    (double)m_download->get_download().get_write_rate().total() / (double)(1 << 20));
- 
-//   else
-//     m_canvas->print(0, 0, "Torrent: Done %.1f MiB Rate: %5.1f / %5.1f KiB Uploaded: %.1f MiB",
-// 		    (double)m_download->get_download().get_bytes_total() / (double)(1 << 20),
-// 		    (double)m_download->get_download().get_write_rate().rate() / 1024.0,
-// 		    (double)m_download->get_download().get_read_rate().rate() / 1024.0,
-// 		    (double)m_download->get_download().get_write_rate().total() / (double)(1 << 20));
-    
-  m_canvas->print(0, 1, "Peers: %i(%i) Min/Max: %i/%i Uploads: %i",
-		  (int)m_download->get_download().get_peers_connected(),
-		  (int)m_download->get_download().get_peers_not_connected(),
-		  (int)m_download->get_download().get_peers_min(),
-		  (int)m_download->get_download().get_peers_max(),
-		  (int)m_download->get_download().get_uploads_max());
+  m_canvas->print(0, 1, "Peers: %i(%i) Min/Max: %i/%i Uploads: %i U/I: %i/%i Failed: %i",
+		  (int)m_download->get_download().peers_connected(),
+		  (int)m_download->get_download().peers_not_connected(),
+		  (int)m_download->get_download().peers_min(),
+		  (int)m_download->get_download().peers_max(),
+		  (int)m_download->get_download().uploads_max(),
+		  (int)m_download->get_download().peers_currently_unchoked(),
+		  (int)m_download->get_download().peers_currently_interested(),
+		  (int)m_download->chunks_failed());
 
   position = print_download_status(buffer, last - buffer, m_download);
   m_canvas->print(0, 2, "[%c:%i] %s",
 		  m_download->get_download().is_tracker_busy() ? 'C' : ' ',
-		  (int)(m_download->get_download().get_tracker_timeout() / 1000000),
+		  (int)(m_download->get_download().tracker_timeout() / 1000000),
 		  buffer);
 }
 
