@@ -58,7 +58,7 @@ WindowHttpQueue::WindowHttpQueue(core::HttpQueue* q) :
 
 void
 WindowHttpQueue::redraw() {
-  utils::displayScheduler.insert(&m_taskUpdate, (utils::Timer::cache() + 1000000).round_seconds());
+  m_slotSchedule(this, (cachedTime + 1000000).round_seconds());
 
   cleanup_list();
 
@@ -79,13 +79,13 @@ WindowHttpQueue::redraw() {
     if (itr->m_http == NULL)
       m_canvas->print(pos, 0, "%s done", itr->m_name.c_str());
 
-    else if (itr->m_http->get_size_total() == 0)
+    else if (itr->m_http->size_total() == 0)
       m_canvas->print(pos, 0, "%s ---%%", itr->m_name.c_str());
 
     else
       m_canvas->print(pos, 0, "%s %3i%%",
 		      itr->m_name.c_str(),
-		      (int)(100.0 * itr->m_http->get_size_done() / itr->m_http->get_size_total()));
+		      (int)(100.0 * itr->m_http->size_done() / itr->m_http->size_total()));
 
     pos += itr->m_name.size() + 6;
     ++itr;
@@ -95,7 +95,7 @@ WindowHttpQueue::redraw() {
 void
 WindowHttpQueue::cleanup_list() {
   for (Container::iterator itr = m_container.begin(); itr != m_container.end();)
-    if (itr->m_http == NULL && itr->m_timer < utils::Timer::cache())
+    if (itr->m_http == NULL && itr->m_timer < cachedTime)
       itr = m_container.erase(itr);
     else
       ++itr;
@@ -105,9 +105,9 @@ WindowHttpQueue::cleanup_list() {
 
 std::string
 WindowHttpQueue::create_name(core::CurlGet* h) {
-  size_t p = h->get_url().rfind('/', h->get_url().size() - std::min<int>(10, h->get_url().size()));
+  size_t p = h->url().rfind('/', h->url().size() - std::min<int>(10, h->url().size()));
 
-  std::string n = p != std::string::npos ? h->get_url().substr(p) : h->get_url();
+  std::string n = p != std::string::npos ? h->url().substr(p) : h->url();
 
   if (n.empty())
     throw std::logic_error("WindowHttpQueue::create_name(...) made a bad string");
@@ -147,7 +147,7 @@ WindowHttpQueue::receive_erase(core::CurlGet* h) {
     throw std::logic_error("WindowHttpQueue::receive_erase(...) tried to remove an object we don't have");
 
   itr->m_http = NULL;
-  itr->m_timer = utils::Timer::cache() + 10000000;
+  itr->m_timer = cachedTime + 10000000;
 
   mark_dirty();
 }
