@@ -37,10 +37,10 @@
 #include "config.h"
 
 #include <stdexcept>
+#include <rak/algorithm.h>
+#include <rak/string_manip.h>
 
 #include "core/download.h"
-#include "rak/algorithm.h"
-#include "utils/parse.h"
 
 #include "window_tracker_list.h"
 
@@ -55,7 +55,7 @@ WindowTrackerList::WindowTrackerList(core::Download* d, unsigned int* focus) :
 void
 WindowTrackerList::redraw() {
   // TODO: Make this depend on tracker signal.
-  utils::displayScheduler.insert(&m_taskUpdate, (utils::Timer::cache() + 10 * 1000000).round_seconds());
+  m_slotSchedule(this, (cachedTime + 10 * 1000000).round_seconds());
   m_canvas->erase();
 
   int pos = 0;
@@ -64,31 +64,31 @@ WindowTrackerList::redraw() {
 
   ++pos;
 
-  if (m_download->get_download().get_tracker_size() == 0)
+  if (m_download->get_download().size_trackers() == 0)
     return;
 
-  if (*m_focus >= m_download->get_download().get_tracker_size())
+  if (*m_focus >= m_download->get_download().size_trackers())
     throw std::logic_error("WindowTrackerList::redraw() called on an object with a bad focus value");
 
   typedef std::pair<unsigned int, unsigned int> Range;
 
   Range range = rak::advance_bidirectional<unsigned int>(0,
 							 *m_focus,
-							 m_download->get_download().get_tracker_size(),
+							 m_download->get_download().size_trackers(),
 							 (m_canvas->get_height() + 1) / 2);
 
   while (range.first != range.second) {
-    torrent::Tracker t = m_download->get_download().get_tracker(range.first);
+    torrent::Tracker t = m_download->get_download().tracker(range.first);
 
     m_canvas->print(0, pos++, "%c %s",
 		    range.first == *m_focus ? '*' : ' ',
-		    t.get_url().c_str());
+		    t.url().c_str());
 
     m_canvas->print(0, pos++, "%c Group: %2i Id: %s Focus: %s Enabled: %s Open: %s",
 		    range.first == *m_focus ? '*' : ' ',
-		    t.get_group(),
-		    utils::escape_string(t.get_tracker_id()).c_str(),
-		    range.first == m_download->get_download().get_tracker_focus() ? "yes" : " no",
+		    t.group(),
+		    rak::copy_escape_html(t.tracker_id()).c_str(),
+		    range.first == m_download->get_download().tracker_focus() ? "yes" : " no",
 		    t.is_enabled() ? "yes" : " no",
 		    t.is_open() ? "yes" : " no");
 
