@@ -62,27 +62,21 @@
 #include "display/manager.h"
 #include "input/bindings.h"
 
-#include "utils/task.h"
-#include "utils/timer.h"
 #include "utils/directory.h"
 
 #include "control.h"
+#include "globals.h"
 #include "signal_handler.h"
 #include "option_file.h"
 #include "option_handler.h"
 #include "option_handler_rules.h"
 #include "option_parser.h"
-
-int64_t utils::Timer::m_cache;
+#include "command_scheduler.h"
+#include "command_scheduler_item.h"
 
 void do_panic(int signum);
 void print_help();
 
-namespace utils {
-  TaskScheduler taskScheduler;
-  TaskScheduler displayScheduler;
-}
-
 bool
 is_resized() {
   static int x = 0;
@@ -98,67 +92,25 @@ is_resized() {
 
 int
 parse_options(Control* c, OptionHandler* optionHandler, int argc, char** argv) {
-  OptionParser optionParser;
+  try {
+    OptionParser optionParser;
 
-  // Converted.
-  optionParser.insert_flag('h', sigc::ptr_fun(&print_help));
+    // Converted.
+    optionParser.insert_flag('h', sigc::ptr_fun(&print_help));
 
-  optionParser.insert_option('b', sigc::bind<0>(sigc::mem_fun(*optionHandler, &OptionHandler::process), "bind"));
-  optionParser.insert_option('d', sigc::bind<0>(sigc::mem_fun(*optionHandler, &OptionHandler::process), "directory"));
-  optionParser.insert_option('i', sigc::bind<0>(sigc::mem_fun(*optionHandler, &OptionHandler::process), "ip"));
-  optionParser.insert_option('p', sigc::bind<0>(sigc::mem_fun(*optionHandler, &OptionHandler::process), "port_range"));
-  optionParser.insert_option('s', sigc::bind<0>(sigc::mem_fun(*optionHandler, &OptionHandler::process), "session"));
+    optionParser.insert_option('b', sigc::bind<0>(sigc::mem_fun(*optionHandler, &OptionHandler::process), "bind"));
+    optionParser.insert_option('d', sigc::bind<0>(sigc::mem_fun(*optionHandler, &OptionHandler::process), "directory"));
+    optionParser.insert_option('i', sigc::bind<0>(sigc::mem_fun(*optionHandler, &OptionHandler::process), "ip"));
+    optionParser.insert_option('p', sigc::bind<0>(sigc::mem_fun(*optionHandler, &OptionHandler::process), "port_range"));
+    optionParser.insert_option('s', sigc::bind<0>(sigc::mem_fun(*optionHandler, &OptionHandler::process), "session"));
 
-  optionParser.insert_option_list('o', sigc::mem_fun(*optionHandler, &OptionHandler::process));
+    optionParser.insert_option_list('o', sigc::mem_fun(*optionHandler, &OptionHandler::process));
 
-  return optionParser.process(argc, argv);
-}
+    return optionParser.process(argc, argv);
 
-void
-initialize_option_handler(Control* c, OptionHandler* optionHandler) {
-  optionHandler->insert("max_peers",           new OptionHandlerInt(c, &apply_download_max_peers, &validate_download_peers));
-  optionHandler->insert("min_peers",           new OptionHandlerInt(c, &apply_download_min_peers, &validate_download_peers));
-  optionHandler->insert("max_uploads",         new OptionHandlerInt(c, &apply_download_max_uploads, &validate_download_peers));
-
-  optionHandler->insert("download_rate",       new OptionHandlerInt(c, &apply_global_download_rate, &validate_rate));
-  optionHandler->insert("upload_rate",         new OptionHandlerInt(c, &apply_global_upload_rate, &validate_rate));
-
-  optionHandler->insert("bind",                new OptionHandlerString(c, &apply_bind, &validate_ip));
-  optionHandler->insert("ip",                  new OptionHandlerString(c, &apply_ip, &validate_ip));
-  optionHandler->insert("port_range",          new OptionHandlerString(c, &apply_port_range, &validate_port_range));
-  optionHandler->insert("port_random",         new OptionHandlerString(c, &apply_port_random, &validate_yes_no));
-
-  optionHandler->insert("check_hash",          new OptionHandlerString(c, &apply_check_hash, &validate_yes_no));
-  optionHandler->insert("directory",           new OptionHandlerString(c, &apply_download_directory, &validate_directory));
-
-  optionHandler->insert("hash_read_ahead",     new OptionHandlerInt(c, &apply_hash_read_ahead, &validate_hash_read_ahead));
-  optionHandler->insert("hash_interval",       new OptionHandlerInt(c, &apply_hash_interval, &validate_hash_interval));
-  optionHandler->insert("hash_max_tries",      new OptionHandlerInt(c, &apply_hash_max_tries, &validate_hash_max_tries));
-  optionHandler->insert("max_open_files",      new OptionHandlerInt(c, &apply_max_open_files, &validate_fd));
-  optionHandler->insert("max_open_sockets",    new OptionHandlerInt(c, &apply_max_open_sockets, &validate_fd));
-  optionHandler->insert("throttle_interval",   new OptionHandlerInt(c, &apply_throttle_interval, &validate_throttle_interval));
-
-  optionHandler->insert("connection_leech",    new OptionHandlerString(c, &apply_connection_leech, &validate_non_empty));
-  optionHandler->insert("connection_seed",     new OptionHandlerString(c, &apply_connection_seed, &validate_non_empty));
-
-  optionHandler->insert("session",             new OptionHandlerString(c, &apply_session_directory, &validate_directory));
-  optionHandler->insert("tracker_dump",        new OptionHandlerString(c, &apply_tracker_dump, &validate_yes_no));
-  optionHandler->insert("use_udp_trackers",    new OptionHandlerString(c, &apply_use_udp_trackers, &validate_yes_no));
-}
-
-void
-load_option_file(const std::string& filename, OptionHandler* optionHandler, bool require = false) {
-  std::fstream f(filename.c_str(), std::ios::in);
-
-  if (!f.is_open()) {
-    std::cout << "Could not open option file \"" << filename << "\"" << std::endl;
-    return;
+  } catch (torrent::input_error& e) {
+    throw std::runtime_error("Failed to parse command line option: " + std::string(e.what()));
   }
-
-  OptionFile optionFile;
-
-  optionFile.slot_option(sigc::mem_fun(*optionHandler, &OptionHandler::process));
-  optionFile.process(&f);
 }
 
 void
@@ -191,68 +143,84 @@ load_arg_torrents(Control* c, char** first, char** last) {
   }
 }
 
+rak::timer
+client_next_timeout() {
+  if (taskScheduler.empty())
+    return 60 * 1000000;
+  else if (taskScheduler.top()->time() <= cachedTime)
+    return 0;
+  else
+    return taskScheduler.top()->time() - cachedTime;
+}
+
 int
 main(int argc, char** argv) {
-  utils::Timer::update();
-
-  OptionHandler optionHandler;
-  Control   uiControl;
-
-  srandom(utils::Timer::cache().usec());
-  srand48(utils::Timer::cache().usec());
-
-  initialize_option_handler(&uiControl, &optionHandler);
-
   try {
 
+    cachedTime = rak::timer::current();
+
+    Control       control;
+    
+    srandom(cachedTime.usec());
+    srand48(cachedTime.usec());
+
+    initialize_option_handler(&control);
+
     SignalHandler::set_ignore(SIGPIPE);
-    SignalHandler::set_handler(SIGINT,  sigc::mem_fun(uiControl, &Control::receive_shutdown));
+    SignalHandler::set_handler(SIGINT,  sigc::mem_fun(control, &Control::receive_shutdown));
     SignalHandler::set_handler(SIGSEGV, sigc::bind(sigc::ptr_fun(&do_panic), SIGSEGV));
     SignalHandler::set_handler(SIGBUS,  sigc::bind(sigc::ptr_fun(&do_panic), SIGBUS));
     SignalHandler::set_handler(SIGFPE,  sigc::bind(sigc::ptr_fun(&do_panic), SIGFPE));
 
-    uiControl.core()->initialize_first();
+    control.core()->initialize_first();
 
-    if (getenv("HOME"))
-      load_option_file(getenv("HOME") + std::string("/.rtorrent.rc"), &optionHandler);
+    OptionFile optionFile;
+    optionFile.slot_option(sigc::mem_fun(control.option_handler(), &OptionHandler::process));
 
-    int firstArg = parse_options(&uiControl, &optionHandler, argc, argv);
+    if (getenv("HOME") && !optionFile.process_file(getenv("HOME") + std::string("/.rtorrent.rc")))
+      control.core()->get_log_important().push_front("Could not load \"~/.rtorrent.rc\".");
 
-    uiControl.initialize();
+    int firstArg = parse_options(&control, control.option_handler(), argc, argv);
 
-    load_session_torrents(&uiControl);
-    load_arg_torrents(&uiControl, argv + firstArg, argv + argc);
+    control.initialize();
 
-    uiControl.display()->adjust_layout();
+    // Just to make sure we did all the stuff on the queue before
+    // loading any torrents.
+    //
+    // Remove this?
+    //rak::priority_queue_perform(&taskScheduler, cachedTime);
 
-    while (!uiControl.is_shutdown_completed()) {
-      utils::Timer::update();
-      utils::taskScheduler.execute(utils::Timer::cache());
+    // Load session torrents and perform scheduled tasks to ensure
+    // session torrents are loaded before arg torrents.
+    load_session_torrents(&control);
+    rak::priority_queue_perform(&taskScheduler, cachedTime);
 
-      // This needs to be called every second or so. Currently done by
-      // the throttle task in libtorrent.
-      if (!utils::displayScheduler.empty() &&
-	  utils::displayScheduler.get_next_timeout() <= utils::Timer::cache())
-	uiControl.display()->do_update();
+    load_arg_torrents(&control, argv + firstArg, argv + argc);
+
+    control.display()->adjust_layout();
+
+    while (!control.is_shutdown_completed()) {
+      control.inc_tick();
+
+      cachedTime = rak::timer::current();
+      rak::priority_queue_perform(&taskScheduler, cachedTime);
 
       // Do shutdown check before poll, not after.
-      uiControl.core()->get_poll_manager()->poll(!utils::taskScheduler.empty() ?
-						    utils::taskScheduler.get_next_timeout() - utils::Timer::cache() :
-						    60 * 1000000);
+      control.core()->get_poll_manager()->poll(client_next_timeout());
     }
 
-    uiControl.cleanup();
+    control.cleanup();
 
   } catch (torrent::base_error& e) {
     display::Canvas::cleanup();
 
-    std::cout << "Caught exception from libtorrent: \"" << e.what() << '"' << std::endl;
+    std::cout << "Caught exception: " << e.what() << std::endl;
     return -1;
 
   } catch (std::exception& e) {
     display::Canvas::cleanup();
 
-    std::cout << "Caught exception: \"" << e.what() << '"' << std::endl;
+    std::cout << e.what() << std::endl;
     return -1;
   }
 
@@ -284,8 +252,6 @@ do_panic(int signum) {
   
   if (signum == SIGBUS)
     std::cout << "A bus error propably means you ran out of diskspace." << std::endl;
-  
-  std::cout << "TO AVOID CORRUPT DOWNLOADS, RUN \"touch\" ON ALL DOWNLOADED FILES OR INITATE HASH RECHECK WITH ^R ON ALL TORRENTS." << std::endl;
 
   exit(-1);
 }
@@ -293,7 +259,7 @@ do_panic(int signum) {
 void
 receive_tracker_dump(std::istream* s) {
   std::stringstream filename;
-  filename << "./tracker_dump." << utils::Timer::current().seconds();
+  filename << "./tracker_dump." << rak::timer::current().seconds();
 
   std::fstream out(filename.str().c_str(), std::ios::out | std::ios::trunc);
 
