@@ -38,12 +38,12 @@
 
 #include <stdexcept>
 #include <rak/functional.h>
+#include <rak/string_manip.h>
 #include <sigc++/bind.h>
 #include <sigc++/hide.h>
 #include <torrent/torrent.h>
 
 #include "core/download.h"
-#include "core/download_factory.h"
 #include "core/manager.h"
 
 #include "input/bindings.h"
@@ -71,7 +71,7 @@ DownloadList::DownloadList(Control* c) :
 
   m_window(c->display()->end()),
 
-  m_windowTitle(new WTitle("rTorrent " VERSION " - libTorrent " + std::string(torrent::get_version()))),
+  m_windowTitle(new WTitle("rTorrent " VERSION " - libTorrent " + std::string(torrent::version()))),
   m_windowHttpQueue(new WHttp(&c->core()->get_http_queue())),
 
   m_uiDownload(NULL),
@@ -85,8 +85,7 @@ DownloadList::DownloadList(Control* c) :
   m_uiArray[DISPLAY_LOG]           = new ElementLogComplete(&m_control->core()->get_log_complete());
   m_windowLog                      = new WLog(&m_control->core()->get_log_important());
 
-  m_taskUpdate.set_iterator(utils::taskScheduler.end());
-  m_taskUpdate.set_slot(sigc::mem_fun(*this, &DownloadList::task_update)),
+  m_taskUpdate.set_slot(rak::mem_fn(this, &DownloadList::task_update)),
 
   setup_keys();
   setup_input();
@@ -112,7 +111,7 @@ DownloadList::activate() {
   if (is_active())
     throw std::logic_error("ui::Download::activate() called on an already activated object");
 
-  utils::taskScheduler.insert(&m_taskUpdate, utils::Timer::cache() + 1000000);
+  priority_queue_insert(&taskScheduler, &m_taskUpdate, cachedTime);
 
   m_windowTextInput->set_active(false);
 
@@ -139,7 +138,7 @@ DownloadList::disable() {
 
   disable_display();
 
-  utils::taskScheduler.erase(&m_taskUpdate);
+  priority_queue_erase(&taskScheduler, &m_taskUpdate);
 
   m_control->display()->erase(m_window);
   m_control->display()->erase(m_windowTitle);
@@ -266,16 +265,9 @@ DownloadList::receive_exit_input(bool useDefault) {
 
   m_control->ui()->window_statusbar()->set_active(true);
   m_windowTextInput->set_active(false);
-
   m_control->input()->set_text_input();
 
-  // Adding download.
-  core::DownloadFactory* f = new core::DownloadFactory(m_windowTextInput->get_input()->str(), m_control->core());
-
-  f->set_start(useDefault);
-  f->slot_finished(sigc::bind(sigc::ptr_fun(&rak::call_delete_func<core::DownloadFactory>), f));
-  f->load();
-  f->commit();
+  m_control->core()->try_create_download_expand(m_windowTextInput->get_input()->str(), useDefault);
 
   // Clean up.
   m_windowTextInput->get_input()->clear();
@@ -304,7 +296,7 @@ void
 DownloadList::task_update() {
   m_windowLog->receive_update();
 
-  utils::taskScheduler.insert(&m_taskUpdate, (utils::Timer::cache() + 1000000).round_seconds());
+  priority_queue_insert(&taskScheduler, &m_taskUpdate, (cachedTime + 1000000).round_seconds());
 }
 
 void
