@@ -60,12 +60,15 @@ public:
 
   WStatusbar*         window_statusbar()            { return m_windowStatusbar; }
 
+  void                set_down_throttle(unsigned int throttle);
+  void                set_up_throttle(unsigned int throttle);
+
+  void                adjust_down_throttle(int throttle);
+  void                adjust_up_throttle(int throttle);
+
 private:
   void                setup_keys();
 
-  void                receive_down_throttle(int t);
-  void                receive_up_throttle(int t);
-
   Control*            m_control;
   DownloadList*       m_downloadList;
 
